@@ -45,11 +45,11 @@
 #' @importFrom graphics abline lines text
 #' @return A matrix containing the confidence interval for the requested contrast
 #' @examples
-#'   #Binomial RD, MOVER-J method:
-#'   moverci(x1 = 5, n1 = 56, x2 = 0, n2 = 29)
+#' # Binomial RD, MOVER-J method:
+#' moverci(x1 = 5, n1 = 56, x2 = 0, n2 = 29)
 #'
-#'   #Binomial RD, Newcombe method:
-#'   moverci(x1 = 5, n1 = 56, x2 = 0, n2 = 29, type = "wilson")
+#' # Binomial RD, Newcombe method:
+#' moverci(x1 = 5, n1 = 56, x2 = 0, n2 = 29, type = "wilson")
 #' @author Pete Laud, \email{p.j.laud@@sheffield.ac.uk}
 #' @references
 #'   Laud PJ. Equal-tailed confidence intervals for comparison of
@@ -57,11 +57,11 @@
 #'
 #'   Newcombe RG. Interval estimation for the difference between independent
 #'   proportions: comparison of eleven methods. Statistics in Medicine 1998;
-#;   17(8):873-890.
+# ;   17(8):873-890.
 #'
 #'   Donner A, Zou G. Closed-form confidence intervals for functions of the
 #'   normal mean and standard deviation. Statistical Methods in Medical Research
-#;   2012; 21(4):347-359.
+# ;   2012; 21(4):347-359.
 #'
 #'   Fagerland MW, Newcombe RG. Confidence intervals for odds ratio and relative
 #'   risk based on the inverse hyperbolic sine transformation. Statistics in
@@ -72,23 +72,21 @@
 #'   Statistics 2014; 29(3-4):869-889.
 #'
 #' @export
-moverci <- function(
-  x1,
-  n1,
-  x2 = NULL,
-  n2 = NULL,
-  a1 = 0.5,
-  b1 = 0.5,
-  a2 = 0.5,
-  b2 = 0.5,
-  cc = FALSE,
-  level = 0.95,
-  distrib = "bin",
-  contrast = "RD",
-  type = "jeff",
-  adj = FALSE,
-  ...
-  ) {
+moverci <- function(x1,
+                    n1,
+                    x2 = NULL,
+                    n2 = NULL,
+                    a1 = 0.5,
+                    b1 = 0.5,
+                    a2 = 0.5,
+                    b2 = 0.5,
+                    cc = FALSE,
+                    level = 0.95,
+                    distrib = "bin",
+                    contrast = "RD",
+                    type = "jeff",
+                    adj = FALSE,
+                    ...) {
   if (!(tolower(substr(type, 1, 4)) %in% c("jeff", "wils", "exac"))) {
     print("Type must be one of 'jeffreys', 'wilson' or 'exact'")
     stop()
@@ -128,7 +126,7 @@ moverci <- function(
   if (as.character(cc) == "TRUE") cc <- 0.5
 
   alpha <- 1 - level
-  z <- qnorm(1 - alpha/2)
+  z <- qnorm(1 - alpha / 2)
 
   lenx <- length(x1)
   # in case x1,x2 are input as vectors but n1,n2 are not
@@ -149,30 +147,42 @@ moverci <- function(
   }
 
   if (type %in% c("wilson", "p")) {
-    p1hat <- x1/n1
-    if (type != "p") p2hat <- x2/n2
+    p1hat <- x1 / n1
+    if (type != "p") p2hat <- x2 / n2
   }
 
   if (type %in% c("jeff", "exact")) {
     if (type == "exact") cc <- 0.5
     # MOVER-J, including optional 'continuity correction'
-    j1 <- jeffreysci(x1, n1, ai = a1, bi = b1, cc = cc, level = level,
-                     distrib = distrib, adj = adj)
+    j1 <- jeffreysci(x1, n1,
+      ai = a1, bi = b1, cc = cc, level = level,
+      distrib = distrib, adj = adj
+    )
     if (contrast != "p") {
-      j2 <- jeffreysci(x2, n2, ai = a2, bi = b2, cc = cc, level = level,
-                     distrib = distrib, adj = adj)
-    } else j2 <- NULL
+      j2 <- jeffreysci(x2, n2,
+        ai = a2, bi = b2, cc = cc, level = level,
+        distrib = distrib, adj = adj
+      )
+    } else {
+      j2 <- NULL
+    }
     p1hat <- j1[, 3]
     p2hat <- j2[, 3]
   } else if (type == "wilson") {
     # or use Wilson intervals as per Newcombe 1998
-    #(NB could add cc here for completeness)
-    j1 <- quadroot(a = 1 + z^2/n1, b = - (2 * p1hat + z^2/n1),
-                   c_ = p1hat^2)
+    # (NB could add cc here for completeness)
+    j1 <- quadroot(
+      a = 1 + z^2 / n1, b = -(2 * p1hat + z^2 / n1),
+      c_ = p1hat^2
+    )
     if (contrast != "p") {
-      j2 <- quadroot(a = 1 + z^2/n2, b = - (2 * p2hat + z^2/n2),
-                   c_ = p2hat^2)
-    } else j2 <- NULL
+      j2 <- quadroot(
+        a = 1 + z^2 / n2, b = -(2 * p2hat + z^2 / n2),
+        c_ = p2hat^2
+      )
+    } else {
+      j2 <- NULL
+    }
   }
   l1 <- j1[, 1]
   u1 <- j1[, 2]
@@ -187,46 +197,46 @@ moverci <- function(
     # From Newcombe (1998), p876 "Method 10"
     lower <- p1hat - p2hat - sqrt(pmax(0, (p1hat - l1)^2 + (u2 - p2hat)^2))
     upper <- p1hat - p2hat + sqrt(pmax(0, (u1 - p1hat)^2 + (p2hat - l2)^2))
-    est <-  p1hat - p2hat
+    est <- p1hat - p2hat
     if (adj == TRUE) {
-      #This is optional for informative priors
+      # This is optional for informative priors
       lower[(x1 == 0 & x2 == n2)] <- -1
       upper[(x1 == n1 & x2 == 0)] <- 1
     }
   } else if (contrast == "OR") {
     # From Fagerland & Newcombe (2013), p2828 "Method 4"
-    q1hat <- p1hat/(1 - p1hat)
-    q2hat <- p2hat/(1 - p2hat)
-    L1 <- l1/(1 - l1)
-    U1 <- u1/(1 - u1)
-    L2 <- l2/(1 - l2)
-    U2 <- u2/(1 - u2)
+    q1hat <- p1hat / (1 - p1hat)
+    q2hat <- p2hat / (1 - p2hat)
+    L1 <- l1 / (1 - l1)
+    U1 <- u1 / (1 - u1)
+    L2 <- l2 / (1 - l2)
+    U2 <- u2 / (1 - u2)
     lower <- pmax(0, (q1hat * q2hat - sqrt(pmax(0, (q1hat * q2hat)^2 -
-               L1 * U2 * (2 * q1hat - L1) * (2 * q2hat - U2)))) /
-                 (U2 * (2 * q2hat - U2)))
+      L1 * U2 * (2 * q1hat - L1) * (2 * q2hat - U2)))) /
+      (U2 * (2 * q2hat - U2)))
     upper <- (q1hat * q2hat + sqrt(pmax(0, (q1hat * q2hat)^2 -
-                U1 * L2 * (2 * q1hat - U1) * (2 * q2hat - L2)))) /
-                  (L2 * (2 * q2hat - L2))
-    est <- p1hat * (1 - p2hat)/(p2hat * (1 - p1hat))
+      U1 * L2 * (2 * q1hat - U1) * (2 * q2hat - L2)))) /
+      (L2 * (2 * q2hat - L2))
+    est <- p1hat * (1 - p2hat) / (p2hat * (1 - p1hat))
     if (adj == TRUE) {
-      #This is optional for informative priors
+      # This is optional for informative priors
       upper[x2 == 0] <- Inf
       lower[(x1 == 0 & x2 == n2) | (x1 == n1 & x2 == 0)] <- 0
       upper[(x1 == 0 & x2 == n2) | (x1 == n1 & x2 == 0)] <- Inf
     }
-    if (cc > 0) lower[u2 == 1] <- 0 #Avoids LCL=NaN
+    if (cc > 0) lower[u2 == 1] <- 0 # Avoids LCL=NaN
   } else if (contrast == "RR") {
     # From Donner & Zou (2012), p351
     # or Li et al. (2014), p873
     lower <- (p1hat * p2hat - sqrt(pmax(0, (p1hat * p2hat)^2 -
-               l1 * (2 * p2hat - u2) * (u2 * (2 * p1hat - l1))))) /
-                  (u2 * (2 * p2hat - u2))
+      l1 * (2 * p2hat - u2) * (u2 * (2 * p1hat - l1))))) /
+      (u2 * (2 * p2hat - u2))
     upper <- (p1hat * p2hat + sqrt(pmax(0, (p1hat * p2hat)^2 -
-               u1 * (2 * p2hat - l2) * (l2 * (2 * p1hat - u1))))) /
-                  (l2 * (2 * p2hat - l2))
-    est <- p1hat/p2hat
+      u1 * (2 * p2hat - l2) * (l2 * (2 * p1hat - u1))))) /
+      (l2 * (2 * p2hat - l2))
+    est <- p1hat / p2hat
     if (adj == TRUE) {
-      #This is optional for informative priors
+      # This is optional for informative priors
       upper[x2 == 0] <- Inf
       lower[(x1 == 0)] <- 0
     }
@@ -265,8 +275,8 @@ moverci <- function(
 #' @importFrom stats qbeta qgamma qnorm
 #' @author Pete Laud, \email{p.j.laud@@sheffield.ac.uk}
 #' @examples
-#'   #Jeffreys method:
-#'   jeffreysci(x = 5, n = 56)
+#' # Jeffreys method:
+#' jeffreysci(x = 5, n = 56)
 #' @references
 #'   Laud PJ. Equal-tailed confidence intervals for comparison of
 #'   rates. Pharmaceutical Statistics 2017; 16:334-348.
@@ -274,17 +284,15 @@ moverci <- function(
 #'   Brown LD, Cai TT, DasGupta A. Interval estimation for a binomial
 #'   proportion. Statistical Science 2001; 16(2):101-133
 #' @export
-jeffreysci <- function(
-  x,
-  n,
-  ai=0.5,
-  bi=0.5,
-  cc=0,
-  level=0.95,
-  distrib="bin",
-  adj=TRUE,
-  ...
-  ) {
+jeffreysci <- function(x,
+                       n,
+                       ai = 0.5,
+                       bi = 0.5,
+                       cc = 0,
+                       level = 0.95,
+                       distrib = "bin",
+                       adj = TRUE,
+                       ...) {
   if (!is.numeric(c(x, n))) {
     print("Non-numeric inputs!")
     stop()
@@ -301,9 +309,9 @@ jeffreysci <- function(
 
   alpha <- 1 - level
   if (distrib == "bin") {
-    CI_lower <- qbeta( alpha/2, x + (ai - cc), n - x + (bi + cc))
-    est <- qbeta( 0.5, x + (ai), n - x + (bi)) #Obtain phat as the median
-    CI_upper <- qbeta(1 - alpha/2, x + (ai + cc), n - x + (bi - cc))
+    CI_lower <- qbeta(alpha / 2, x + (ai - cc), n - x + (bi + cc))
+    est <- qbeta(0.5, x + (ai), n - x + (bi)) # Obtain phat as the median
+    CI_upper <- qbeta(1 - alpha / 2, x + (ai + cc), n - x + (bi - cc))
     if (adj == TRUE) {
       # adjustment at boundary values
       CI_lower[x == 0] <- 0
@@ -314,13 +322,13 @@ jeffreysci <- function(
   } else if (distrib == "poi") {
     # Jeffreys prior for Poisson rate uses gamma distribution,
     # as defined in Li et al. with "continuity correction" from Laud 2017.
-    CI_lower <- qgamma(alpha/2, x + (ai - cc), scale = 1/n)
-    est <- qgamma( 0.5, x + (ai), scale = 1/n)
+    CI_lower <- qgamma(alpha / 2, x + (ai - cc), scale = 1 / n)
+    est <- qgamma(0.5, x + (ai), scale = 1 / n)
     if (adj == TRUE) {
-      CI_lower[x == 0] <-  0
-      est[x == 0] <-  0
+      CI_lower[x == 0] <- 0
+      est[x == 0] <- 0
     }
-    CI_upper <- qgamma(1 - alpha/2, (x + (ai + cc)), scale = 1/n)
+    CI_upper <- qgamma(1 - alpha / 2, (x + (ai + cc)), scale = 1 / n)
   }
   CI <- cbind(Lower = CI_lower, Upper = CI_upper, est = est)
   CI
@@ -346,21 +354,19 @@ jeffreysci <- function(
 #'   priors for Poisson rates require only a1, a2.
 #' @inheritParams moverci
 #' @export
-moverbci <- function(
-  x1,
-  n1,
-  x2,
-  n2,
-  a1 = 0.5,
-  b1 = 0.5,
-  a2 = 0.5,
-  b2 = 0.5,
-  distrib = "bin",
-  contrast = "RD",
-  level = 0.95,
-  cc = 0,
-  ...
-) {
+moverbci <- function(x1,
+                     n1,
+                     x2,
+                     n2,
+                     a1 = 0.5,
+                     b1 = 0.5,
+                     a2 = 0.5,
+                     b2 = 0.5,
+                     distrib = "bin",
+                     contrast = "RD",
+                     level = 0.95,
+                     cc = 0,
+                     ...) {
   moverci(
     x1 = x1,
     n1 = n1,
@@ -383,8 +389,8 @@ moverbci <- function(
 # Internal function
 quadroot <- function(a, b, c_) {
   # GET ROOTS OF A QUADRATIC EQUATION
-  r1x <- ( - b + sqrt(b^2 - 4 * a * c_) )/(2 * a)
-  r2x <- ( - b - sqrt(b^2 - 4 * a * c_) )/(2 * a)
+  r1x <- (-b + sqrt(b^2 - 4 * a * c_)) / (2 * a)
+  r2x <- (-b - sqrt(b^2 - 4 * a * c_)) / (2 * a)
   r1 <- pmin(r1x, r2x)
   r2 <- pmax(r1x, r2x)
   cbind(r1, r2)
